@@ -227,7 +227,6 @@ class FactTestCase(unittest.TestCase):
         
         self.assertEqual(len(dimensionsWithNulls), 0)
 
-    @unittest.skipIf(self.__linkedDimensionTables == None or len(self.__linkedDimensionTables) == 0)
     def test_dimension_id_values_in_dimension(self) -> None:
         
         '''
@@ -237,6 +236,9 @@ class FactTestCase(unittest.TestCase):
                     d.2) Values in dimension Id column of fact should be present in actual dimension
         '''
 
+        if(self.__linkedDimensionTables == None or len(self.__linkedDimensionTables) == 0):
+            self.skipTest("the set of linked dimensions cannot be empty or None to run this test...")
+
         event = TestEvent(Utilities.get_function_caller_name())
 
         eventCode1 = "keys-with-bad-values"
@@ -277,7 +279,6 @@ class FactTestCase(unittest.TestCase):
 
         self.assertEqual(len(keysWithBadValues), 0)
 
-    @unittest.skipIf(self.__linkedDimensionTables == None or len(self.__linkedDimensionTables) == 0)
     def test_key_column_name_in_dimension(self) -> None:
         
         '''
@@ -287,6 +288,9 @@ class FactTestCase(unittest.TestCase):
                     d.4) Name of Dimension Id column should match to the actual column name in dimension table except in cases where the fact table relates to same dimension using multiple columns. In such cases, the relevant name should be added before DimensionId. E.g. DIM_StartDateId, DIM_EndDateId
         '''
 
+        if(self.__linkedDimensionTables == None or len(self.__linkedDimensionTables) == 0):
+            self.skipTest("the set of linked dimensions cannot be empty or None to run this test...")
+
         event = TestEvent(Utilities.get_function_caller_name())
 
         eventCode1 = "keys-not-in-dimension"
