@@ -9,7 +9,7 @@ class FactTestSuite(BaseTestSuite):
     def __init__(self, sparkSession: SparkSession, databaseName: str, tableName: str, linkedDimensions: [(str, str)], excludeFromAggregation: [str] = []):
         super(FactTestSuite, self).__init__(sparkSession, databaseName, tableName)
         self.__linkedDimensions = linkedDimensions
-        self.__excludeFromAggregations = excludeFromAggregations
+        self.__excludeFromAggregation = excludeFromAggregation
 
     def queue_tests(self) -> None:
 
@@ -18,7 +18,7 @@ class FactTestSuite(BaseTestSuite):
         names = loader.getTestCaseNames(FactTestCase)
 
         for name in names:
-            self.TestSuite.addTest(FactTestCase(self.SparkSession, self.TableDataFrame, self.FieldInfo, self.__linkedDimensions, self.DatabaseName, self.TableName, self.TableCount, self.CustomEvents, self.__excludeFromAggregations))
+            self.TestSuite.addTest(FactTestCase(self.SparkSession, self.TableDataFrame, self.FieldInfo, self.__linkedDimensions, self.DatabaseName, self.TableName, self.TableCount, self.CustomEvents, self.__excludeFromAggregation))
 
         names = loader.getTestCaseNames(CommonTestCase)
 
